==> ktd-0.0.3.tar.gz: ktd-0.0.3/ktd/ktd.py <==
# coding: utf-8
# email: khahux@163.com

import json
import sys

import getopt
from urllib import quote
import urllib2

from termcolor import colored


KEYFROM = 'khahux'
KEY = '1132608537'
DOCTYPE = 'json'

URL = 'http://fanyi.youdao.com/openapi.do?keyfrom={keyform}&key={key}&type=data&doctype={doctype}&version=1.1&q='


def get_res(keyword):
    url = URL.format(keyform=KEYFROM, key=KEY, doctype=DOCTYPE) + quote(keyword)
    return urllib2.urlopen(url).read()


def show_terminal(res):
    try:
        read_res = json.loads(res)
    except:
        print
        print colored('请联网使用!(Connected to the Internet, please!)', 'green')
        print
        return
    if read_res['errorCode'] == 20:
        print colored('要翻译的文本过长', 'red')
    elif read_res['errorCode'] == 30:
        print colored('无法进行有效的翻译', 'red')
    elif read_res['errorCode'] == 40:
        print colored('不支持的语言类型', 'red')
    elif read_res['errorCode'] == 50:
        print colored('无效的key', 'green')
    elif read_res['errorCode'] == 60:
        print colored('无词典结果', 'green')
    elif read_res['errorCode'] == 0:
        try:
            print
            print '----------------------'
            print '| ' + colored('translation:', 'yellow') + colored(read_res['translation'][0], 'green')
            print '----------------------'
            print '| ' + colored('--phonetic-:', 'yellow') + colored(read_res['basic']['phonetic'], 'green')
            print '----------------------'
            print
        except:
            print '----------------------'
    else:
        print
        print '呵呵,我也不知咋回事!(500)'
        print
        return


def usage():
    print 
    print 'this is ktd usage:'
    print 
    print '-h, --help: print help message.'
    print '-v, --version: print script version'
    print 


def example():
    print 
    print 'examples'
    print 
    print '$ktd hello'
    print '----------------------'
    print '| translation:你好'    
    print '----------------------'
    print '| --phonetic-:hə\'ləʊ; he-'
    print '----------------------'
    print 
    print '$ktd 你'
    print '----------------------'
    print '| translation:you'
    print '----------------------'
    print '| --phonetic-:nǐ'
    print '----------------------'
    print 


def version():
    print 
    print 'ktd 0.0.3'
    print 


def main():
    try:
        options, args = getopt.getopt(sys.argv[1:], 'ho:v', ['help'])
    except getopt.GetoptError, err:
        print str(err)
        usage()
        example()
        sys.exit(2)
    for o, a in options:
        if o in ('-h', '--help'):
            usage()
            example()
            sys.exit(1)
        elif o in ('-v', '--version'):
            version()
            sys.exit(0)
        else:
            assert False, 'unhandled option'

    keyword = " ".join(args).lower()
    if keyword == '':
        example()
        return
    res = get_res(keyword)
    show_terminal(res)


if __name__ == '__main__':
    main()

==> ktd-0.0.4.tar.gz: ktd-0.0.4/ktd/ktd.py <==
# coding: utf-8
# email: khahux@163.com

import json
import sys

import getopt
from urllib import quote
import urllib2

from termcolor import colored


KEYFROM = 'khahux'
KEY = '1132608537'
DOCTYPE = 'json'

URL = 'http://fanyi.youdao.com/openapi.do?keyfrom={keyform}&key={key}&type=data&doctype={doctype}&version=1.1&q='


def get_res(keyword):
    url = URL.format(keyform=KEYFROM, key=KEY, doctype=DOCTYPE) + quote(keyword)
    return urllib2.urlopen(url).read()


def show_terminal(res):
    try:
        read_res = json.loads(res)
    except:
        print
        print colored('请联网使用!(Connected to the Internet, please!)', 'green')
        print
        return
    if read_res['errorCode'] == 20:
        print colored('要翻译的文本过长', 'red')
    elif read_res['errorCode'] == 30:
        print colored('无法进行有效的翻译', 'red')
    elif read_res['errorCode'] == 40:
        print colored('不支持的语言类型', 'red')
    elif read_res['errorCode'] == 50:
        print colored('无效的key', 'green')
    elif read_res['errorCode'] == 60:
        print colored('无词典结果', 'green')
    elif read_res['errorCode'] == 0:
        try:
            print
            print '----------------------'
            print '| ' + colored('translation:', 'yellow') + colored(read_res['translation'][0], 'green')
            print '----------------------'
            print '| ' + colored('--phonetic-:', 'yellow') + colored(read_res['basic']['phonetic'], 'green')
            print '----------------------'
            print
        except:
            print '----------------------'
    else:
        print
        print '呵呵,我也不知咋回事!(500)'
        print
        return


def usage():
    print
    print 'this is ktd usage:'
    print
    print '-h, --help: print help message.'
    print '-v, --version: print script version'
    print


def example():
    print
    print 'examples'
    print
    print '$ktd hello'
    print '----------------------'
    print '| translation:你好'
    print '----------------------'
    print '| --phonetic-:hə\'ləʊ; he-'
    print '----------------------'
    print
    print '$ktd 你'
    print '----------------------'
    print '| translation:you'
    print '----------------------'
    print '| --phonetic-:nǐ'
    print '----------------------'
    print


def version():
    print
    print 'ktd 0.0.4'
    print


def main():
    try:
        options, args = getopt.getopt(sys.argv[1:], 'hv', ['help', 'version'])
    except getopt.GetoptError, err:
        print str(err)
        usage()
        example()
        sys.exit(2)
    for o, a in options:
        if o in ('-h', '--help'):
            usage()
            example()
            sys.exit(1)
        elif o in ('-v', '--version'):
            version()
            sys.exit(0)
        else:
            assert False, 'unhandled option'

    keyword = " ".join(args).lower()
    if keyword == '':
        example()
        return
    res = get_res(keyword)
    show_terminal(res)


if __name__ == '__main__':
    main()
